# crimm-dock
Docking modules for crimm

This module is an extension to the crimm package. Currently it provides functions for FFT Docking of small molecule probes.
To build from source, use
```
pip install crimm-dock
```
This module uses FFTW3. You will need to have FFTW3F lib in your library path in order to compile the C-Extension
The easiest way of installing FFTW is `conda install fftw`
